Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(192)

Unified Diff: appengine/findit/crash/suspect.py

Issue 2586343002: renamed the "Suspects" class to "SuspectMap", to reduce confusion. (Closed)
Patch Set: Created 4 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « appengine/findit/crash/changelist_classifier.py ('k') | appengine/findit/crash/test/crash_test_suite.py » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: appengine/findit/crash/suspect.py
diff --git a/appengine/findit/crash/suspect.py b/appengine/findit/crash/suspect.py
index 98ef1004e0712a63b1c9f666034827ac03383667..edc8bf5a0486046edb379cff56d5b9a208628269 100644
--- a/appengine/findit/crash/suspect.py
+++ b/appengine/findit/crash/suspect.py
@@ -166,16 +166,16 @@ def _DistanceBetweenLineRanges((start1, end1), (start2, end2)):
return max(0, start2 - end1, start1 - end2)
-class Suspects(dict):
+class SuspectMap(dict):
"""A map from revisions to the ``Suspect`` object for that revision."""
def __init__(self, ignore_cls=None):
- super(Suspects, self).__init__()
+ super(SuspectMap, self).__init__()
self._ignore_cls = ignore_cls
def GenerateSuspects(self, file_path, dep_path, stack_infos, changelogs,
blame):
"""Compute suspects from a list of CLs, and store them.
Suspects are generated based on newly found file path, its stack_infos,
and all the changelogs that touched this file in the dep in regression
« no previous file with comments | « appengine/findit/crash/changelist_classifier.py ('k') | appengine/findit/crash/test/crash_test_suite.py » ('j') | no next file with comments »
@@ -166,16 +166,16 @@ def _DistanceBetweenLineRanges((start1, end1), (start2, end2)):
def GenerateSuspects(self, file_path, dep_path, stack_infos, changelogs,
blame):
- """Compute suspects from a list of CLs, and store them.
+ """Compute suspects from a list of CLs, and store them in this map.
Suspects are generated based on newly found file path, its stack_infos,
and all the changelogs that touched this file in the dep in regression

Powered by Google App Engine
This is Rietveld 408576698